Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(295)

Unified Diff: Source/bindings/scripts/CodeGeneratorV8.pm

Issue 15797004: Cleanup WebKit prefixed names for classes in css directory. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/bindings/v8/custom/V8CSSRuleCustom.cpp » ('j') | Source/core/css/CSSRegionRule.idl » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/bindings/scripts/CodeGeneratorV8.pm
diff --git a/Source/bindings/scripts/CodeGeneratorV8.pm b/Source/bindings/scripts/CodeGeneratorV8.pm
index 1d74697f1387891dcfa95fecb9a92e8e558e76e1..2b27f1ca071424cef14dbfd8c17673ce27804b5b 100644
--- a/Source/bindings/scripts/CodeGeneratorV8.pm
+++ b/Source/bindings/scripts/CodeGeneratorV8.pm
@@ -543,9 +543,9 @@ sub GetIndexedGetterFunction
{
my $interface = shift;
- # FIXME: Expose indexed getter of WebKitCSSMixFunctionValue by removing this special case
- # because CSSValueList(which is parent of WebKitCSSMixFunctionValue) has indexed property getter.
- if ($interface->name eq "WebKitCSSMixFunctionValue") {
+ # FIXME: Expose indexed getter of CSSMixFunctionValue by removing this special case
+ # because CSSValueList(which is parent of CSSMixFunctionValue) has indexed property getter.
+ if ($interface->name eq "CSSMixFunctionValue") {
return 0;
}
« no previous file with comments | « no previous file | Source/bindings/v8/custom/V8CSSRuleCustom.cpp » ('j') | Source/core/css/CSSRegionRule.idl » ('J')

Powered by Google App Engine
This is Rietveld 408576698